import type { WritableComputedRef } from "@vue/reactivity";
import { EffectScope } from "vue";
import { LifeCycleEvent } from "../Common/LifeCycle";
import type { StoreMetaActionData } from "./Meta/StoreMetaActionData";
import type { StoreMetaData } from "./Meta/StoreMetaData";
import type { StoreMetaGetterSetterData } from "./Meta/StoreMetaGetterSetterData";
import type { BaseStore } from "./Store";
interface BaseStorePublic {
    vueBinding: string;
    __scope: EffectScope;
    __storeMeta: StoreMetaData;
    __getters: StoreGettersList;
    __setters: StoreSettersList;
    __actions: StoreActionsList;
    __lifecycleHooks: LifeCycleHooks;
    __extensions: StoreExtensionDefinitions;
}
export declare type StoreType = {
    [K in keyof typeof BaseStore['prototype']]: K extends keyof BaseStorePublic ? never : typeof BaseStore['prototype'][K];
} & BaseStorePublic;
export declare type TestingStoreType = {
    ___getMetaData(): StoreMetaData;
} & StoreType;
export declare type LifeCycleHooks = {
    [LifeCycleEvent.BeforeAll]?: () => void | PromiseLike<void>;
    [LifeCycleEvent.OnInit]?: () => void | PromiseLike<void>;
    [LifeCycleEvent.OnDispose]?: () => void | PromiseLike<void>;
    [LifeCycleEvent.AfterAll]?: () => void | PromiseLike<void>;
};
export declare type StoreMetaModuleData = {
    [key: string]: {
        [key: string]: any;
    };
};
export declare type BasicStoreMetaInfo = {
    className?: string;
    exportName?: string;
    vueBinding?: string;
};
export declare type StoreMetaInfo = BasicStoreMetaInfo & {
    module?: () => StoreMetaModuleData;
};
export declare type StoreMeta = {
    store: StoreMetaInfo;
    stateKeys: string[];
    getters: {
        [key: string]: StoreMetaGetterSetterData;
    };
    setters: {
        [key: string]: StoreMetaGetterSetterData;
    };
    actions: {
        [key: string]: StoreMetaActionData;
    };
    lifeCycleHandlers: {
        [key: string]: LifeCycleEvent | string;
    };
};
export declare type StoreLoaderModule = {
    stores: StoreMetaData[];
};
export declare enum MutationType {
    Direct = "direct",
    PatchObject = "patch object",
    PatchFunction = "patch function"
}
export declare type StoreExtensionDefinitions = {
    getters: {
        [key: string]: () => any;
    };
    actions: {
        [key: string]: () => any;
    };
    properties: {
        [key: string]: any;
    };
};
export declare type StoreGetterComputedInfo = {
    type: 'computed';
    value: WritableComputedRef<any>;
    getter: () => any;
    setter?: (value: any) => void;
};
export declare type StoreGetterRegularInfo = {
    type: 'function';
    value: () => any;
};
export declare type StoreGetterInfo = StoreGetterComputedInfo | StoreGetterRegularInfo;
export declare type StoreSetterInfo = {
    type: 'function';
    value: (val: any) => void;
};
export declare type StoreGettersList = {
    [key: string]: StoreGetterInfo;
};
export declare type StoreSettersList = {
    [key: string]: StoreSetterInfo;
};
export declare type StoreActionsList = {
    [key: string]: (...args: any[]) => any;
};
export declare type HotReloadChange<T> = {
    added: T;
    removed: T;
};
export declare type HotReloadChanges = {
    actions: HotReloadChange<StoreMetaActionData[]>;
    getters: HotReloadChange<StoreMetaGetterSetterData[]>;
    setters: HotReloadChange<StoreMetaGetterSetterData[]>;
    state: HotReloadChange<StoreMeta['stateKeys']>;
    hasChanges(): boolean;
};
export {};
