"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mergeReactiveObjects = exports.isPlainObject = void 0;
const vue_1 = require("vue");
function isPlainObject(obj) {
    return (obj &&
        typeof obj === 'object' &&
        Object.prototype.toString.call(obj) === '[object Object]' &&
        typeof obj.toJSON !== 'function');
}
exports.isPlainObject = isPlainObject;
function mergeReactiveObjects(target, patchToApply) {
    // Handle Map instances
    if (target instanceof Map && patchToApply instanceof Map) {
        patchToApply.forEach((value, key) => target.set(key, value));
    }
    // Handle Set instances
    if (target instanceof Set && patchToApply instanceof Set) {
        patchToApply.forEach(target.add, target);
    }
    // no need to go through symbols because they cannot be serialized anyway
    for (const key in patchToApply) {
        if (!patchToApply.hasOwnProperty(key))
            continue;
        const subPatch = patchToApply[key];
        const targetValue = target[key];
        if (isPlainObject(targetValue) &&
            isPlainObject(subPatch) &&
            target.hasOwnProperty(key) &&
            !(0, vue_1.isRef)(subPatch) &&
            !(0, vue_1.isReactive)(subPatch)) {
            //@ts-ignore
            target[key] = mergeReactiveObjects(targetValue, subPatch);
        }
        else {
            // @ts-expect-error: subPatch is a valid value
            target[key] = subPatch;
        }
    }
    return target;
}
exports.mergeReactiveObjects = mergeReactiveObjects;
//# sourceMappingURL=Object.js.map