"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createLazyImportGlobNode = exports.createRelativeImportNode = exports.createImportNode = exports.formatImportString = void 0;
const typescript_1 = __importDefault(require("typescript"));
const { factory } = typescript_1.default;
function formatImportString(importString, isRelativeImport = true) {
    if (importString.endsWith('.ts')) {
        importString = importString.substring(0, importString.length - 3);
    }
    if (!importString.startsWith('./') && isRelativeImport) {
        importString = './' + importString;
    }
    return importString;
}
exports.formatImportString = formatImportString;
function createImportNode(importNames, specifier, isTypeOnly = false) {
    return factory.createImportDeclaration(undefined, factory.createImportClause(false, undefined, factory.createNamedImports(importNames.map(name => factory.createImportSpecifier(isTypeOnly, undefined, factory.createIdentifier(name))))), factory.createStringLiteral(specifier), undefined);
}
exports.createImportNode = createImportNode;
/**
 * importNames = import {this, is, the, names} from 'x';
 *
 * @param {string[]} importNames
 * @param {string} relativeFilePath
 * @param {boolean} isTypeOnly
 * @returns {ts.ImportDeclaration}
 */
function createRelativeImportNode(importNames, relativeFilePath, isTypeOnly = false) {
    return createImportNode(importNames, formatImportString(relativeFilePath, true), isTypeOnly);
}
exports.createRelativeImportNode = createRelativeImportNode;
function createLazyImportGlobNode(importPath) {
    return factory.createArrowFunction(undefined, undefined, [], undefined, factory.createToken(typescript_1.default.SyntaxKind.EqualsGreaterThanToken), factory.createCallExpression(factory.createPropertyAccessExpression(factory.createMetaProperty(typescript_1.default.SyntaxKind.ImportKeyword, factory.createIdentifier("meta")), factory.createIdentifier("glob")), undefined, [
        factory.createStringLiteral(importPath),
        factory.createObjectLiteralExpression([factory.createPropertyAssignment(factory.createIdentifier("eager"), factory.createTrue())], false)
    ]));
}
exports.createLazyImportGlobNode = createLazyImportGlobNode;
//# sourceMappingURL=Imports.js.map