"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.unwrappableNode = exports.UnwrappableNode = exports.createNodeFromValue = exports.createObjectNode = exports.newClassInstance = void 0;
const typescript_1 = __importDefault(require("typescript"));
const { factory } = typescript_1.default;
function newClassInstance(name, params) {
    return factory.createNewExpression(factory.createIdentifier(name), undefined, params);
}
exports.newClassInstance = newClassInstance;
/**
 * This will convert the object passed to it, to typescript AST nodes so it can be printed.
 * Ex:
 * createObjectNode({key : value});
 *
 * @param obj
 * @returns {ts.ObjectLiteralExpression}
 */
function createObjectNode(obj) {
    return factory.createObjectLiteralExpression(Object.entries(obj).map(([key, value]) => {
        return factory.createPropertyAssignment(factory.createIdentifier(key), createNodeFromValue(value));
    }), true);
}
exports.createObjectNode = createObjectNode;
function createNodeFromValue(value) {
    let nodeResult = null;
    if (value instanceof UnwrappableNode) {
        nodeResult = value.node;
    }
    else if (typeof value == "undefined") {
        nodeResult = factory.createIdentifier("undefined");
    }
    else if (value === null) {
        nodeResult = factory.createIdentifier("null");
    }
    else if (typeof value == "string") {
        nodeResult = factory.createStringLiteral(value);
    }
    else if (typeof value == "number") {
        nodeResult = factory.createNumericLiteral(value);
    }
    else if (typeof value == "boolean") {
        nodeResult = value ? factory.createTrue() : factory.createFalse();
    }
    else if (typeof value == "bigint") {
        nodeResult = factory.createBigIntLiteral(value);
    }
    else if (typeof value == "symbol") {
        nodeResult = factory.createIdentifier(value.toString());
    }
    else if (Array.isArray(value)) {
        nodeResult = factory.createArrayLiteralExpression(value.map(createNodeFromValue));
    }
    else if (typeof value == "object") {
        nodeResult = createObjectNode(value);
    }
    if (!nodeResult) {
        throw new Error("Unknown value type: " + typeof value);
    }
    //	Context.printNode(nodeResult);
    return nodeResult;
}
exports.createNodeFromValue = createNodeFromValue;
class UnwrappableNode {
    constructor(node) {
        Object.defineProperty(this, "node", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: node
        });
    }
}
exports.UnwrappableNode = UnwrappableNode;
function unwrappableNode(node) {
    return new UnwrappableNode(node);
}
exports.unwrappableNode = unwrappableNode;
//# sourceMappingURL=Object.js.map