"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createStoreLoaderModule = void 0;
const typescript_1 = __importDefault(require("typescript"));
const Imports_1 = require("./Imports");
const Object_1 = require("./Object");
const { factory } = typescript_1.default;
function createStoreLoaderModule(stores) {
    const imports = [
        (0, Imports_1.createImportNode)(['StoreManager', 'StoreMetaData', 'StoreMetaActionData', 'StoreMetaGetterSetterData'], '@idevelopthings/vue-class-stores/vue'),
    ];
    const storeMetaObjects = stores.map(store => {
        return (0, Object_1.newClassInstance)("StoreMetaData", [(0, Object_1.createNodeFromValue)(store.toMetaObject())]);
    });
    const storeMetaExport = factory.createVariableStatement([factory.createModifier(typescript_1.default.SyntaxKind.ExportKeyword)], factory.createVariableDeclarationList([
        factory.createVariableDeclaration(factory.createIdentifier("stores"), undefined, undefined, factory.createArrayLiteralExpression(storeMetaObjects, false))
    ], typescript_1.default.NodeFlags.Const));
    return [
        ...imports,
        storeMetaExport,
        //		createConstVariableNode("stores", stores.map(store => store.toMetaObject()), false, true),
        //		createBootStoresFunction(),
        //		createViteHotAccept(stores)
    ];
}
exports.createStoreLoaderModule = createStoreLoaderModule;
/**
 * Creates our boot function which is like:
 *
 * export function bootStores(app: App) {
 * 	StoreManager.boot(app, stores);
 * }
 *
 * @returns {ts.FunctionDeclaration}
 */
function createBootStoresFunction() {
    return factory.createFunctionDeclaration([factory.createModifier(typescript_1.default.SyntaxKind.ExportKeyword)], undefined, factory.createIdentifier("bootStores"), undefined, [factory.createParameterDeclaration(undefined, undefined, factory.createIdentifier("app"), undefined, factory.createTypeReferenceNode(factory.createIdentifier("App"), undefined), undefined)], undefined, factory.createBlock([factory.createExpressionStatement(factory.createCallExpression(factory.createPropertyAccessExpression(factory.createIdentifier("StoreManager"), factory.createIdentifier("boot")), undefined, [
            factory.createIdentifier("app"),
            factory.createIdentifier("stores")
        ]))], true));
}
function createViteHotAccept(stores) {
    const storeImports = stores.map(store => factory.createStringLiteral((0, Imports_1.formatImportString)(store.loaderImportPath)));
    //	storeImports.push(factory.createStringLiteral(
    //		formatImportString(path.relative(path.dirname(PluginConfig.storeLoaderPath), PluginConfig.storeLoaderPath))
    //	))
    return factory.createIfStatement(factory.createPropertyAccessExpression(factory.createMetaProperty(typescript_1.default.SyntaxKind.ImportKeyword, factory.createIdentifier("meta")), factory.createIdentifier("hot")), factory.createBlock([factory.createExpressionStatement(factory.createCallExpression(factory.createPropertyAccessExpression(factory.createPropertyAccessExpression(factory.createMetaProperty(typescript_1.default.SyntaxKind.ImportKeyword, factory.createIdentifier("meta")), factory.createIdentifier("hot")), factory.createIdentifier("accept")), undefined, [
            factory.createArrayLiteralExpression(storeImports, false),
            factory.createArrowFunction(undefined, undefined, [factory.createParameterDeclaration(undefined, undefined, factory.createIdentifier("modules"), undefined, undefined, undefined)], undefined, factory.createToken(typescript_1.default.SyntaxKind.EqualsGreaterThanToken), factory.createBlock([
                factory.createExpressionStatement(factory.createCallExpression(factory.createPropertyAccessExpression(factory.createIdentifier("console"), factory.createIdentifier("log")), undefined, [
                    factory.createStringLiteral("stores updated"),
                    factory.createIdentifier("modules")
                ])),
                factory.createExpressionStatement(factory.createCallExpression(factory.createPropertyAccessExpression(factory.createIdentifier("StoreManager"), factory.createIdentifier("handleHotReload")), undefined, [factory.createIdentifier("modules")]))
            ], true))
        ]))], true), undefined);
}
//# sourceMappingURL=StoreLoader.js.map