"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.errorMessages = exports.CodeSnippet = void 0;
const Common_1 = require("../Common");
const Logger_1 = require("./Logger");
const ProcessingContext_1 = require("./Utils/ProcessingContext");
class CodeSnippet {
    constructor(content = '', exampleText = 'Example:', includeCodeSnippet = false, includeCodeSnippetLocation = null) {
        Object.defineProperty(this, "content", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: content
        });
        Object.defineProperty(this, "exampleText", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: exampleText
        });
        Object.defineProperty(this, "includeCodeSnippet", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: includeCodeSnippet
        });
        Object.defineProperty(this, "includeCodeSnippetLocation", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: includeCodeSnippetLocation
        });
    }
    get canIncludeCodeSnippet() {
        return this.includeCodeSnippet && this.includeCodeSnippetLocation;
    }
}
exports.CodeSnippet = CodeSnippet;
exports.errorMessages = {
    stateGetter: {
        publicOrPrivate: () => [
            `The 'state' property must be public or private.`,
            new CodeSnippet(`get state(): IMyStoreType {\n\treturn { ... }\n}`),
        ],
        nonStatic: () => [
            `The 'state' property must not be static.`,
            new CodeSnippet(`get state(): IMyStoreType {\n\treturn { ... }\n}`),
        ],
        invalidBody: () => [
            `The 'state' getter must have a body with a single return object statement.`,
            new CodeSnippet(`get state(): IMyStoreType {\n\treturn { ... }\n}`),
        ],
        mustBeGetter: () => [
            `The 'state' property must be a JS/TS getter.`,
            new CodeSnippet(`get state(): IMyStoreType {\n\treturn { ... }\n}`),
        ],
        missingStateGetter: (className) => [
            'Could not find state getter object for store: ' + className,
            'Ensure you have a state object for your store',
            new CodeSnippet(`get state() : IMyStateType {\n\treturn { ... };\n}`),
        ]
    },
    store: {
        missingExport: (className) => [
            'Could not find export for your store: ' + Logger_1.colors.WrapBold(className),
            'You need to define an export for your store class so it can be used',
            new CodeSnippet(`export const ${(0, Common_1.createExportName)(className)} = new ${className}();`, 'For example, add this to the end of your module:', true, 'before'),
        ]
    },
    lifecycle: {
        multipleLifeCycleHandlersDefinedForMethod: (methodName, currentEvent, storeName) => {
            storeName = storeName || ProcessingContext_1.ProcessingContext.store.className;
            return [
                `"${storeName}.${methodName}" has multiple lifecycle decorators defined, there should only be one.`,
                `The first will be used.`,
                new CodeSnippet(`@${currentEvent}\n${methodName}() { ... }`, 'For example, your method should look like this:'),
            ];
        },
        multipleLifeCycleHandlersDefinedForEvent: (methodName, storeName) => {
            storeName = storeName || ProcessingContext_1.ProcessingContext.store.className;
            return [
                `Your have defined multiple methods using the same lifecycle decorator: "${storeName}.${methodName}". There should only be one.`,
            ];
        },
    }
};
//# sourceMappingURL=ErrorMessages.js.map