import ts from "typescript";
import { StoreMeta } from "./Meta/StoreMeta";
export declare class Context {
    /**
     * When we first load our stores, we'll take a hash of the content
     * Later on this hash will be used when there is a change, mainly to
     * determine if we need to do some file writes, when writing stores.d.ts,
     * even if contents are the same, this makes vite do a full page reload...
     * @type {Map<string, string>}
     */
    storeFileHashes: Map<string, string>;
    /**
     * All of the store modules in our project
     *
     * @type {{module: ts.SourceFile, store: StoreMeta}[]}
     */
    modules: {
        module: ts.SourceFile;
        store: StoreMeta;
    }[];
    /**
     * All of our store meta classes which hold information on all our stores.
     *
     * @type {StoreMeta[]}
     */
    stores: StoreMeta[];
    init(): void;
    /**
     * Load all of our store modules and create a "store meta" class.
     */
    reloadModules(reloadFilePaths?: boolean): void;
    /**
     * Create a file hash for the specified file path + content
     *
     * This will be used to prevent over-writing to the FS when the content is the same
     *
     * @param {string} filePath
     * @param {string} content
     * @returns {boolean}
     * @private
     */
    private addFileHash;
    /**
     * Quick helper method to setup file hashes for generated files
     *
     * @param {string} file
     * @private
     */
    private loadGeneratedFileHash;
    /**
     * MAKE SURE TO PASS A FULL ABSOLUTE PATH TO THIS METHOD!
     *
     * @param {string} filePath
     * @returns {boolean}
     * @private
     */
    private fileHasChanged;
    process(): void;
    writeFiles(): void;
    private writeStoreDeclaration;
    rebuild(): void;
    private processModule;
    isStoreFile(path: string): boolean;
    getStoreByFilePath(path: string): StoreMeta | undefined;
    private writeTsFile;
    private writeFile;
    static printNode(node: any): void;
}
