"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isTestingEnv = void 0;
const typescript_1 = __importDefault(require("typescript"));
const Classes_1 = require("./AstHelpers/Classes");
const Modifiers_1 = require("./AstHelpers/Modifiers");
const Imports_1 = require("./Builders/Imports");
const Object_1 = require("./Builders/Object");
const StoreMeta_1 = require("./Meta/StoreMeta");
const { factory } = typescript_1.default;
class TestContext {
    constructor(context, sourceFile) {
        Object.defineProperty(this, "context", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "sourceFile", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
        Object.defineProperty(this, "stores", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: new Map()
        });
        this.context = context;
        this.sourceFile = sourceFile;
    }
    addStore(declaration) {
        var _a, _b;
        const name = (_b = (_a = declaration.name) === null || _a === void 0 ? void 0 : _a.getText()) !== null && _b !== void 0 ? _b : 'unknown';
        const meta = new StoreMeta_1.StoreMeta(this.sourceFile);
        this.stores.set(name, { name, store: meta, declaration });
        return meta;
    }
}
function isTestingEnv() {
    var _a;
    return ((_a = process === null || process === void 0 ? void 0 : process.env) === null || _a === void 0 ? void 0 : _a.NODE_ENV) === 'test';
}
exports.isTestingEnv = isTestingEnv;
let testContext = new TestContext(undefined, undefined);
function TransformerFactory(program) {
    return function (context) {
        testContext = new TestContext(context, undefined);
        return function (sourceFile) {
            testContext.sourceFile = sourceFile;
            if (!isTestingEnv()) {
                return sourceFile;
            }
            if (!sourceFile.fileName.toLowerCase().endsWith('spec.ts') &&
                !sourceFile.fileName.toLowerCase().endsWith('test.ts')) {
                return sourceFile;
            }
            // Locate any store definitions inside the test file, when we find one, we'll add it to the "TestContext"
            sourceFile = visitNodeAndChildren(sourceFile, program, context);
            if (testContext.stores.size === 0) {
                return sourceFile;
            }
            return factory.updateSourceFile(sourceFile, [
                // Ensure we import the classes needed for metadata
                (0, Imports_1.createImportNode)(['StoreManager', 'StoreMetaData', 'StoreMetaActionData', 'StoreMetaGetterSetterData'], '@idevelopthings/vue-class-stores/vue'),
                ...sourceFile.statements,
            ], false, sourceFile.referencedFiles, sourceFile.typeReferenceDirectives, sourceFile.hasNoDefaultLib, sourceFile.libReferenceDirectives);
            return sourceFile;
        };
    };
}
exports.default = TransformerFactory;
function visitNodeAndChildren(node, program, context) {
    return typescript_1.default.visitEachChild(visitNode(node, program), childNode => visitNodeAndChildren(childNode, program, context), context);
}
function visitNode(node, program) {
    const typeChecker = program.getTypeChecker();
    if (!typescript_1.default.isClassDeclaration(node))
        return node;
    if (!typescript_1.default.canHaveDecorators(node))
        return node;
    if (!(0, Modifiers_1.hasDecorator)(node, 'TestStore'))
        return node;
    if (!(0, Classes_1.extendsStore)(node))
        return node;
    const store = testContext.addStore(node);
    store.process(node);
    const metaMethod = factory.createMethodDeclaration(undefined, undefined, factory.createIdentifier("___getMetaData"), undefined, undefined, [], undefined, factory.createBlock([
        factory.createReturnStatement((0, Object_1.newClassInstance)("StoreMetaData", [(0, Object_1.createNodeFromValue)(store.toMetaObject())]))
    ], true));
    node = factory.updateClassDeclaration(node, node.modifiers, node.name, node.typeParameters, node.heritageClauses, [...node.members, metaMethod]);
    return node;
}
//# sourceMappingURL=Transformer.js.map